summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/managedconnectionaccount.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/managedconnectionaccount.h')
-rw-r--r--kopete/libkopete/managedconnectionaccount.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/kopete/libkopete/managedconnectionaccount.h b/kopete/libkopete/managedconnectionaccount.h
index 7d864dfc..1de3a7ad 100644
--- a/kopete/libkopete/managedconnectionaccount.h
+++ b/kopete/libkopete/managedconnectionaccount.h
@@ -27,7 +27,7 @@ namespace Kopete
class Protocol;
/**
* A ManagedConnectionAccount queries the NetworkStatus KDED Module before trying to connect using
* connectwithPassword, starting a network connection if needed. If the network is not available,
* it delays calling performConnectWithPassword until it receives notification from the daemon
* that the network is up. The account receiveds notifications from the daemon of network failures
@@ -36,15 +36,16 @@ class Protocol;
class KOPETE_EXPORT ManagedConnectionAccount : public PasswordedAccount
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* @brief ManagedConnectionAccount constructor.
* @param parent The protocol this account connects via
* @param acctId The ID of this account - should be unique within this protocol
* @param maxPasswordLength The maximum length for passwords for this account, or 0 for no limit
- * @param name The name for this QObject
+ * @param name The name for this TQObject
*/
- ManagedConnectionAccount( Protocol *parent, const TQString &acctId, uint maxPasswordLength = 0, const char *name = 0 );
+ ManagedConnectionAccount( Protocol *tqparent, const TQString &acctId, uint maxPasswordLength = 0, const char *name = 0 );
public slots:
/**
* @brief Begin the connection process, by checking if the connection is available with the ConnectionManager.
@@ -68,7 +69,7 @@ class KOPETE_EXPORT ManagedConnectionAccount : public PasswordedAccount
* @param host For future expansion.
* @param status the new status of the network
*/
- virtual void slotConnectionStatusChanged( const TQString & host, NetworkStatus::EnumStatus status );
+ virtual void slotConnectionStatusChanged( const TQString & host, NetworktqStatus::EnumtqStatus status );
private:
TQString m_password;
bool m_waitingForConnection;
@@ -27,7 +27,7 @@ namespace Kopete
class Protocol;
/**
- * A ManagedConnectionAccount queries the NetworkStatus KDED Module before trying to connect using
+ * A ManagedConnectionAccount queries the NetworktqStatus KDED Module before trying to connect using
* connectwithPassword, starting a network connection if needed. If the network is not available,
* it delays calling performConnectWithPassword until it receives notification from the daemon
@@ -36,15 +36,16 @@ class Protocol;
/**
* @brief ManagedConnectionAccount constructor.
- * @param parent The protocol this account connects via
+ * @param tqparent The protocol this account connects via
* @param acctId The ID of this account - should be unique within this protocol
* @param maxPasswordLength The maximum length for passwords for this account, or 0 for no limit